==> openeclass-4.0.2.tar.gz: openeclass-4.0.2/lang/de/common.inc.php <==
<?php
/*
 *  ========================================================================
 *  * Open eClass
 *  * E-learning and Course Management System
 *  * ========================================================================
 *  * Copyright 2003-2024, Greek Universities Network - GUnet
 *  *
 *  * Open eClass is an open platform distributed in the hope that it will
 *  * be useful (without any warranty), under the terms of the GNU (General
 *  * Public License) as published by the Free Software Foundation.
 *  * The full license can be read in "/info/license/license_gpl.txt".
 *  *
 *  * Contact address: GUnet Asynchronous eLearning Group
 *  *                  e-mail: info@openeclass.org
 *  * ========================================================================
 *
 */

// Message file for language de
// Generated 2024-01-19 17:14:54

$langCourse = "Kurs";
$langEclass = "Open eClass - die asynchrone E-Learning Plattform";
$langTeacher = "Dozent";
$langOfTeacher = "Dozenten";
$langTeachers = "Dozenten";
$langOfTeachers = "Dozenten";
$langsTeacher = "dozent";
$langsOfTeacher = "dozenten";
$langsTeachers = "dozenten";
$langsOfTeachers = "dozenten";
$langStudent = "Student";
$langOfStudent = "Studenten";
$langStudents = "Studenten";
$langOfStudents = "Studenten";
$langsStudent = "Student";
$langsOfStudent = "Studenten";
$langsStudents = "Studenten";
$langsOfStudents = "Studenten";
$langsOfStudentss = "Studenten";
$langsstudent_acc = "Student";
$langGuest = "Gast Benutzer";
$langGuests = "Gast Benutzer";
$langFaculty = "Fakultät";
$langOfFaculty = "Fakultät";
$langOfFaculties = "Fakultäten";
$langFaculties = "Fakultäten";
$langsFaculty = "Fakultät";
$langsFaculties = "Fakultäten";
$langpre = "Typ: Grundstudium";
$langpost = "Typ: Postgraduiertes Studium";
$langother = "Typ: Postgraduiertes Studium";
$langInfoAbout = "Die Plattform eClass realisiert ein integriertes System für die Verwaltung von elektronischen 
Unterrichtsfächern (Kursen).
Der Entwurf orientiert sich an der Unterstützung des konventionellen Unterrichts unter Zuhilfenahme 
von Informatiktechnologien, welche im Bereich der Erziehungswissenschaften bereits Einzug gehalten 
haben.
Sie verfolgt die Philosophie des offenen Quellkodes und unterstützt den Dienst des asynchronen 
E-Learnings ohne Beschränkungen und Verpflichtungen.
Der Zugang zum Dienst erfolgt mit Hilfe eines einfachen Browsers ohne Zuhilfenahme von 
speziellen technischen Fertigkeiten
Die Zielsetzung besteht in der Förderung des Unterrichtsprozesses, indem den Teilnehmern eine 
dynamische, interaktive Arbeitsumgebung sowie eine stetige Kommunikation zwischen Ausbildern und 
Lernenden geboten wird.
Im einzelnen unterstützt die Plattform den Ausbilder bei der elektronischen Verwaltung, der 
Speicherung und Präsentation des Unterrichtsmaterials. Außerdem stellt sie dem Lernenden einen 
alternativen Kanal zur individuellen Bildung zur Verfügung, welcher unabhängig von zeitlichen 
und räumlichen Zwängen ist.";
$langExtrasLeft = '';
$langExtrasRight = '';
$langCourses = "Kurse";
$langGroupTutor = "Group Tutor";
$langEditor = "Assistent des Dozenten";
$langOfEditor = "Tutor Assistant";
$langsEditor = "tutor assistant";
$langsOfEditor = "tutor assistant";
$langsOfGroupTutor = "group tutor";
$langOfCourse = "Course";
$langOfCourses = "Courses";
$langsCourse = "course";
$langsCourses = "courses";
$langsOfCourse = "course";
$langsOfCourses = "courses";
$langCourseAdmin = "Admin";
$langOfCourseAdmin = "Admin";
$langCourseAdmins = "Admins";
$langOfCourseAdmins = "Admins";
$langsCourseAdmin = "admin";
$langsOfCourseAdmin = "admin";
$langsCourseAdmins = "admins";
$langsOfCourseAdmins = "admins";
$langCourseAdminTeacher = "Admin - Teacher";
$langOfCourseAdminTeacher = "Admin - Teacher";
$langCourseAdminTeachers = "Admins - Teachers";
$langOfCourseAdminTeachers = "Admins - Teachers";
$langsCourseAdminTeacher = "admin - teacher";
$langsOfCourseAdminTeacher = "admin - teacher";
$langsCourseAdminTeachers = "admins - teachers";
$langsOfCourseAdminTeachers = "admins - teachers";
$langCourseReviewer = "Reviewer";
$langOfCourseReviewer = "Reviewer";
$langsCourseReviewer = "reviewer";
$langsOfCourseReviewer = "reviewer";

==> openeclass-4.2.1.tar.gz: openeclass-4.2.1/lang/de/common.inc.php <==
<?php

// Message file for language de
// Generated 2025-12-02 16:31:15

$langCourse = "Kurs";
$langEclass = "Open eClass - die asynchrone E-Learning Plattform";
$langTeacher = "Dozent";
$langOfTeacher = "Dozenten";
$langTeachers = "Dozenten";
$langOfTeachers = "Dozenten";
$langsTeacher = "dozent";
$langsOfTeacher = "dozenten";
$langsTeachers = "dozenten";
$langsOfTeachers = "dozenten";
$langStudent = "Student";
$langOfStudent = "Studenten";
$langStudents = "Studenten";
$langOfStudents = "Studenten";
$langsStudent = "Student";
$langsOfStudent = "Studenten";
$langsStudents = "Studenten";
$langsOfStudents = "Studenten";
$langsOfStudentss = "Studenten";
$langsstudent_acc = "Student";
$langGuest = "Gast Benutzer";
$langGuests = "Gast Benutzer";
$langFaculty = "Fakultät";
$langOfFaculty = "Fakultät";
$langOfFaculties = "Fakultäten";
$langFaculties = "Fakultäten";
$langsFaculty = "Fakultät";
$langsFaculties = "Fakultäten";
$langpre = "Typ: Grundstudium";
$langpost = "Typ: Postgraduiertes Studium";
$langother = "Typ: Postgraduiertes Studium";
$langInfoAbout = "Die Plattform eClass realisiert ein integriertes System für die Verwaltung von elektronischen 
Unterrichtsfächern (Kursen).
Der Entwurf orientiert sich an der Unterstützung des konventionellen Unterrichts unter Zuhilfenahme 
von Informatiktechnologien, welche im Bereich der Erziehungswissenschaften bereits Einzug gehalten 
haben.
Sie verfolgt die Philosophie des offenen Quellkodes und unterstützt den Dienst des asynchronen 
E-Learnings ohne Beschränkungen und Verpflichtungen.
Der Zugang zum Dienst erfolgt mit Hilfe eines einfachen Browsers ohne Zuhilfenahme von 
speziellen technischen Fertigkeiten
Die Zielsetzung besteht in der Förderung des Unterrichtsprozesses, indem den Teilnehmern eine 
dynamische, interaktive Arbeitsumgebung sowie eine stetige Kommunikation zwischen Ausbildern und 
Lernenden geboten wird.
Im einzelnen unterstützt die Plattform den Ausbilder bei der elektronischen Verwaltung, der 
Speicherung und Präsentation des Unterrichtsmaterials. Außerdem stellt sie dem Lernenden einen 
alternativen Kanal zur individuellen Bildung zur Verfügung, welcher unabhängig von zeitlichen 
und räumlichen Zwängen ist.";
$langExtrasLeft = '';
$langExtrasRight = '';
$langCourses = "Kurse";
$langGroupTutor = "Group Tutor";
$langEditor = "Assistent des Dozenten";
$langOfEditor = "Tutor Assistant";
$langsEditor = "tutor assistant";
$langsOfEditor = "tutor assistant";
$langsOfGroupTutor = "group tutor";
$langOfCourse = "Course";
$langOfCourses = "Courses";
$langsCourse = "course";
$langsCourses = "courses";
$langsOfCourse = "course";
$langsOfCourses = "courses";
$langsOfFaculty = "category";
$langCourseAdmin = "Admin";
$langOfCourseAdmin = "Admin";
$langCourseAdmins = "Admins";
$langOfCourseAdmins = "Admins";
$langsCourseAdmin = "admin";
$langsOfCourseAdmin = "admin";
$langsCourseAdmins = "admins";
$langsOfCourseAdmins = "admins";
$langCourseAdminTeacher = "Admin - Teacher";
$langOfCourseAdminTeacher = "Admin - Teacher";
$langCourseAdminTeachers = "Admins - Teachers";
$langOfCourseAdminTeachers = "Admins - Teachers";
$langsCourseAdminTeacher = "admin - teacher";
$langsOfCourseAdminTeacher = "admin - teacher";
$langsCourseAdminTeachers = "admins - teachers";
$langsOfCourseAdminTeachers = "admins - teachers";
$langCourseReviewer = "Reviewer";
$langOfCourseReviewer = "Reviewer";
$langsCourseReviewer = "reviewer";
$langsOfCourseReviewer = "reviewer";
$langCTeacher = "INSTRUCTOR";
$langCStudent = "LEARNER";
$langCStudent2 = "STUDENT";
$langAlignment = "Alignment";
$langWidth = "Width";
$langAlignLeft = "Left";
$langAlignCenter = "Center";
$langAlignRight = "Right";
